@@ -1,8 +1,9 @@
 #' Deprecated functions in lidR
 #'
-#' These functions are provided for compatibility with older versions of lidR but are deprecated
-#' since lidR version 3. They will progressively print a message, throw a warning and eventually be
-#' removed. The links below point to the documentation of the new names \cr\cr
+#' These functions are provided for compatibility with older versions of lidR but are deprecated. They
+#' will progressively print a message, throw a warning and eventually be removed. The links below point
+#' to the documentation of the new names. In version 4 they now throw an error. In version 4.1 they
+#' ill be removed definitively.\cr\cr
 #' \link[=add_attribute]{lasadd} \link[=las_check]{lascheck} \link[=clip]{lasclip}
 #' \link[=segment_shapes]{lasdetectshape} \link[=filter_poi]{lasfilter}
 #' \link[=filter_surfacepoints]{lasfiltersurfacepoints} \link[=retrieve_flightlines]{lasflightline}
@@ -13,8 +14,8 @@
 #' \link[=retrieve_scanlines]{lasscanlines} \link[=smooth_height]{lassmooth}
 #' \link[=segment_snags]{lassnags}
 #' \link[=segment_trees]{lastrees} \link[=voxelize_points]{lasvoxelize}
-#' \link[=track_sensor]{sensor_tracking} \link[=find_trees]{tree_detection}
-#' \link[=delineate_crowns]{tree_hull}
+#' \link[=track_sensor]{sensor_tracking} \link[=locate_trees]{tree_detection}
+#' \link[=crown_metrics]{tree_hull}
 #'
 #' @param las See the new functions that replace the old ones
 #' @param geometry See the new functions that replace the old ones
@@ -32,7 +33,6 @@
 #' @param na.rm,use_class,add_lasattribute See the new functions that replace the old ones
 #' @param sensor,Rs,f,gpstime,elevation See the new functions that replace the old ones
 #' @param xscale,yscale,zscale,xoffset,yoffset,zoffset See the new functions that replace the old ones
-#' @param CRSobj See the new functions that replace the old ones
 #' @param size,method,shape,sigma See the new functions that replace the old ones
 #' @param uniqueness See the new functions that replace the old ones
 #' @param interval,pmin,extra_check,thin_pulse_with_time See the new functions that replace the old ones
@@ -260,13 +260,6 @@ lassnags = function(las, algorithm, attribute = "snagCls") {
   return(segment_snags(las, algorithm, attribute))
 }
 
-#' @export
-#' @rdname deprecated
-lastransform = function(las, CRSobj) {
-  .lidr3depreciation("spTransform")
-  return(spTransform(las, CRSobj))
-}
-
 #' @export
 #' @rdname deprecated
 lastrees = function(las, algorithm, attribute = "treeID", uniqueness = 'incremental') {
@@ -320,8 +313,8 @@ sensor_tracking <- function(las, interval = 0.5, pmin = 50, extra_check = TRUE,
 #' @export
 #' @rdname deprecated
 tree_detection = function(las, algorithm) {
-  .lidr3depreciation("find_trees")
-  return(find_trees(las, algorithm))
+  .lidr3depreciation("locate_trees")
+  return(locate_trees(las, algorithm))
 }
 
 #' @export
@@ -335,7 +328,32 @@ tree_hulls = function(las, type = c("convex", "concave", "bbox"), concavity = 3,
 #' @rdname deprecated
 hexbin_metrics = function(...)
 {
-  stop("hexbin_metrics() was an unused function and has been removed from lidR. It can be retrieved in lidRplugins https://github.com/Jean-Romain/lidRplugins")
+  .lidr3depreciation("hexagon_metrics")
+}
+
+#' @export
+#' @rdname deprecated
+filter_surfacepoints = function(las, res)
+{
+  UseMethod("filter_surfacepoints", las)
+}
+
+#' @rdname deprecated
+#' @export
+filter_surfacepoints.LAS = function(las, res)
+{
+  return(decimate_points(las, highest(res)))
+}
+
+#' @rdname deprecated
+#' @export
+filter_surfacepoints.LAScatalog = function(las, res)
+{
+  opt_select(las)       <- "*"
+  opt_chunk_buffer(las) <- res
+  options <- list(need_buffer = FALSE, drop_null = TRUE, need_output_file = TRUE)
+  output  <- catalog_map(las, filter_surfacepoints, res = res, .options = options)
+  return(output)
 }
 
 .lidr3depreciation <- function(name)
@@ -349,9 +367,9 @@ hexbin_metrics = function(...)
   #return(invisible())
 
   # warning v3.2.0
-  msg = paste(as.character(sys.call(sys.parent()))[1L], "is deprecated. Use", name, "instead.")
-  warning(msg, call. = FALSE)
-  return(invisible())
+  #msg = paste(as.character(sys.call(sys.parent()))[1L], "is deprecated. Use", name, "instead.")
+  #warning(msg, call. = FALSE)
+  #return(invisible())
 
   # error v3.3.0
   msg = paste(as.character(sys.call(sys.parent()))[1L], "is defunct. Use", name, "instead.")
@@ -359,6 +377,4 @@ hexbin_metrics = function(...)
   return(invisible())
 }
 
-
-
 # nocov end
