@@ -7,7 +7,7 @@ test_that("plot LAS works", {
   skip_on_cran()
 
   expect_error(plot(las), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 })
 
 test_that("plot LAS works with attributes", {
@@ -20,25 +20,25 @@ test_that("plot LAS works with attributes", {
   las@data$B <- 125
 
   expect_error(plot(las, color = "Intensity"), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 
   expect_error(plot(las, color = "Classification"), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 
   expect_error(plot(las, color = "ScanAngleRank"), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 
   expect_error(plot(las, color = "ReturnNumber"), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 
   expect_error(plot(las, color = "Synthetic_flag"), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 
   expect_error(plot(las, color = "treeID"), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 
   expect_error(plot(las, color = "RGB", nbits = 8), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 })
 
 test_that("plot LAS does not work with missing attributes", {
@@ -79,28 +79,28 @@ test_that("plot lasmetrics3d works", {
   skip_on_cran()
   x = voxel_metrics(las, ~length(Z), 5)
   expect_error(plot(x), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 })
 
 test_that("plot dtm3 works", {
   skip_on_cran()
   x = grid_terrain(las, 1, knnidw())
   expect_error(plot_dtm3d(x), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 })
 
 test_that("add dtm3d works", {
   skip_on_cran()
   x = grid_terrain(las, 1, knnidw())
   expect_error({y = plot(las) ; add_dtm3d(y, x)}, NA)
-  rgl::rgl.close()
+  rgl::close3d()
 })
 
 test_that("add treetop3d works", {
   skip_on_cran()
   x = locate_trees(las, lmf(3))
   expect_error({y = plot(las) ; add_treetops3d(y, x)}, NA)
-  rgl::rgl.close()
+  rgl::close3d()
 })
 
 test_that("add = x overlay a second point cloud", {
@@ -110,7 +110,7 @@ test_that("add = x overlay a second point cloud", {
 
   x = plot(ngnd)
   expect_error(plot(gnd, color = "Classification", add = x), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 
 })
 
@@ -120,14 +120,14 @@ test_that("plot voxels", {
   v <- voxel_metrics(example, func = ~length(Z))
 
   expect_error(plot(v, voxel = TRUE), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 
   expect_error(plot(v, voxel = 2), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 
   attr(v, "res") = NULL
 
   expect_error(plot(v, voxel = TRUE), NA)
-  rgl::rgl.close()
+  rgl::close3d()
 })
 
